@@ -179,13 +179,15 @@ class Invalid(Exception):
             return str(self.pos)
         return str(self.node.name)
 
-    def asdict(self, translate=None):
+    def asdict(self, translate=None, separator='; '):
         """ Return a dictionary containing a basic
         (non-language-translated) error report for this exception.
 
         If ``translate`` is supplied, it must be a callable taking a
         translation string as its sole argument and returning a localized,
         interpolated string.
+
+        If ``separator`` is supplied, error messages are joined with that.
         """
         paths = self.paths()
         errors = {}
@@ -198,7 +200,12 @@ class Invalid(Exception):
                 keyname and keyparts.append(keyname)
             if translate:
                 msgs = [translate(msg) for msg in msgs]
-            errors['.'.join(keyparts)] = '; '.join(interpolate(msgs))
+            msgs = interpolate(msgs)
+            if separator:
+                msgs = separator.join(msgs)
+            else:
+                msgs = list(msgs)
+            errors['.'.join(keyparts)] = msgs
         return errors
 
     def __str__(self):
@@ -1159,7 +1166,7 @@ Seq = Sequence
 class String(SchemaType):
     """ A type representing a Unicode string.
 
-    This type constructor accepts one argument:
+    This type constructor accepts two arguments:
 
     ``encoding``
        Represents the encoding which should be applied to value
@@ -1212,11 +1219,17 @@ class String(SchemaType):
        encoding.  If this is not true, an :exc:`colander.Invalid`
        error will result.
 
+    ``allow_empty``
+       Boolean, if True allows deserialization of an empty string. If
+       False (default), empty strings will deserialize to
+       :attr:`colander.null`
+
     The subnodes of the :class:`colander.SchemaNode` that wraps
     this type are ignored.
     """
-    def __init__(self, encoding=None):
+    def __init__(self, encoding=None, allow_empty=False):
         self.encoding = encoding
+        self.allow_empty = allow_empty
 
     def serialize(self, node, appstruct):
         if appstruct is null:
@@ -1240,6 +1253,9 @@ class String(SchemaType):
                             mapping={'val':appstruct, 'err':e})
                           )
     def deserialize(self, node, cstruct):
+        if cstruct == '' and self.allow_empty:
+            return text_type('')
+
         if not cstruct:
             return null
 
@@ -2100,9 +2116,12 @@ class _SchemaNode(object):
         """ Clone the schema node and return the clone.  All subnodes
         are also cloned recursively.  Attributes present in node
         dictionaries are preserved."""
-        cloned = self.__class__(self.typ)
-        cloned.__dict__.update(self.__dict__)
-        cloned.children = [ node.clone() for node in self.children ]
+        children = [node.clone() for node in self.children]
+        cloned = self.__class__(self.typ, *children)
+
+        attributes = self.__dict__.copy()
+        attributes.pop('children', None)
+        cloned.__dict__.update(attributes)
         return cloned
 
     def bind(self, **kw):
